function [pr,sdev]=gp2_iden_schur_r(p,M,y,N)

% GP2_IDEN_SCHUR_R  This function computes the Gaussian Process Prediction 
% and Standard Deviation given the following inputs, for time-series ONLY.
%
% This is a fast algorithm using Generalised Schur algorithm to perform
% computation task, impossible by standard MATLAB command. The Schur
% algorithm includes Hyperbolic rotation.
%
% [pr,sdev] = GP2_IDEN_SCHUR_R(p,M,y,N)
%
% Inputs:   p   : hyperparameters, [a g v]
%           M   : one-dimensional input column vector
%           y   : one-dimensional output column vector
%           N   : one-dimensional input prediction column vector
%
% Outputs:  pr      = prediction
%           sdev    = standard deviation
%
%
% (C) Gaussian Process Schur Toolbox 1.0
% (C) Copyright 2005-2007, Keith Neo <keith.neo@nuim.ie>
%                          http://www.hamilton.ie

G=get_eigen_block_iden3b(M,N,y,p);
[pr,sd1]=schur_iden3b_r(G,y);
sdev=sqrt(p(1)-sd1);